# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertyRequestChild(Model):
    """PropertyRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param property_id: Required.
    :type property_id: int
    :param property_required: Required.
    :type property_required: bool
    """

    _validation = {
        'property_id': {'required': True},
        'property_required': {'required': True},
    }

    _attribute_map = {
        'property_id': {'key': 'PropertyId', 'type': 'int'},
        'property_required': {'key': 'PropertyRequired', 'type': 'bool'},
    }

    def __init__(self, *, property_id: int, property_required: bool, **kwargs) -> None:
        super(PropertyRequestChild, self).__init__(**kwargs)
        self.property_id = property_id
        self.property_required = property_required
