# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorAlarmStateResponse(Model):
    """IndicatorAlarmStateResponse.

    All required parameters must be populated in order to send to Azure.

    :param current_value:
    :type current_value: float
    :param last_update:
    :type last_update: datetime
    :param id: Required.
    :type id: str
    :param alarm_severity:
    :type alarm_severity: int
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'current_value': {'key': 'CurrentValue', 'type': 'float'},
        'last_update': {'key': 'LastUpdate', 'type': 'iso-8601'},
        'id': {'key': 'Id', 'type': 'str'},
        'alarm_severity': {'key': 'AlarmSeverity', 'type': 'int'},
    }

    def __init__(self, *, id: str, current_value: float=None, last_update=None, alarm_severity: int=None, **kwargs) -> None:
        super(IndicatorAlarmStateResponse, self).__init__(**kwargs)
        self.current_value = current_value
        self.last_update = last_update
        self.id = id
        self.alarm_severity = alarm_severity
